==> haskell-colour-2.3.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.3
id: colour-2.3.3-4GTcWhusU4z5FdC5GspM4b
key: colour-2.3.3-4GTcWhusU4z5FdC5GspM4b
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
author: Russell O'\''Connor
exposed: True
indefinite: False
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
abi: cf36c1b6f2aa814cbe9c4fb4c35cd187
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/colour-2.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/colour-2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.3-4GTcWhusU4z5FdC5GspM4b
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: colour
version: 2.3.4
id: colour-2.3.4-4FOR755TjbXCteGD5Oe26Q
key: colour-2.3.4-4FOR755TjbXCteGD5Oe26Q
license: MIT
maintainer: Russell O'\''Connor <roconnor@theorem.ca>
homepage: http://www.haskell.org/haskellwiki/Colour
synopsis: A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.
category: data, graphics
author: Russell O'\''Connor
exposed: True
indefinite: False
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear
hidden-modules: Data.Colour.Internal Data.Colour.Chan
                Data.Colour.RGB Data.Colour.Matrix Data.Colour.CIE.Chromaticity
abi: 5a3580e6fb04cd83bff9a9ebb80037e2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/colour-2.3.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/colour-2.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-colour
hs-libraries: HScolour-2.3.4-4FOR755TjbXCteGD5Oe26Q
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html: /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
